# Cloud.iO Common Package
![version](https://img.shields.io/pypi/v/cloudio-common-python.svg)
![coverage](docs/images/coverage.svg)

This project makes part of [cloud.iO](https://cloudio.hevs.ch/).

The [cloudio-common-python](https://pypi.org/project/cloudio-common-python/) project contains 
packages/modules used by other cloudio python packages.

Packages provided:
 - [core](src/cloudio/common/core)
 - [mqtt](src/cloudio/common/mqtt)
 - [utils](src/cloudio/common/utils)

To install this package, enter the following command in a console:
```bash
$ pip install cloudio-common-python
```

For more details please refer to the internal documentation.
